OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} е налична. Намерете допълнителна информация за това как да актуализирате.",
    "Channel updated" : "Канала е променен",
    "Web updater is disabled" : "Уеб програмата за актуализиране е деактивирана",
    "Update notifications" : "Известия за актуализации",
    "The update server could not be reached since %d days to check for new updates." : "Няма връзка със сървъра за актуализации от %d дни.",
    "Please check the Nextcloud and server log files for errors." : "Проверете журналите на Nextcloud и на сървъра за грешки.",
    "Update to %1$s is available." : "Налична е актуализация до версия %1$s.",
    "Update to {serverAndVersion} is available." : "Налична е актуализация на {serverAndVersion}.",
    "Update for {app} to version %s is available." : "Обновление за {app} до версия %s е налично.",
    "Update notification" : "Известие за актуализация",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Показва известия за актуализация за Nextcloud и предоставя SSO за програмата за актуализиране.",
    "Update" : "Обновяване",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Инсталираната версия вече не се поддържа. Моля актуализирайте до поддържана версия възможно най-скоро.",
    "Apps missing compatible version" : "Липсва съвместима версия на приложенията",
    "View in store" : "Преглед в магазина",
    "Apps with compatible version" : "Приложения със съвместима версия",
    "Open updater" : "Отвори актуализиращата програма",
    "Download now" : "Свали сега",
    "What's new?" : "Какви са промените?",
    "View changelog" : "Преглед на списъка с промени",
    "The update check is not yet finished. Please refresh the page." : "Проверката за актуализации не е приключила. Заредете страницата отново.",
    "Your version is up to date." : "Ползвате последната версия.",
    "A non-default update server is in use to be checked for updates:" : "Проверката за налични актуализации се извършва чрез сървър, който е различен от стандартния:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Винаги може да актуализирате до по-нова версия. Но не може да се върнете до по-стабилна (по-стара) версия.",
    "Notify members of the following groups about available updates:" : "Известявай следните групи при наличие на актуализация:",
    "No groups" : "Няма групи",
    "Only notifications for app updates are available." : "Налични са само известия за актуализации на приложенията.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Избрания канал за актуализации прави известията за този сървър остарели.",
    "The selected update channel does not support updates of the server." : "Избрания канал за актуализации не поддържа сървърни актуализации.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Налична е нова версия: <strong>{newVersionString}</strong>",
    "Checking apps for compatible versions" : "Проверка на приложенията за съвместими версии",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Моля, уверете се, че в config.php не е зададено <samp>appstoreenabled</samp> на false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Свързването с магазина за приложения App Store не е възможно или изобщо не са върнати актуализации. Търсете ръчно за актуализации или се уверете, че вашият сървър има достъп до интернет и може да се свърже с App Store.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Всички</strong>  приложения имат налична съвместима версия за тази версия на Nextcloud.",
    "Enterprise" : "Предприятие",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "За професионална употреба. Осигурява винаги най-новото ниво на корекция, но няма да се актуализира веднага до следващото голямо издание. Тази актуализация се случва, след като Nextcloud GmbH направи допълнително подсилване и тестване за широкомащабни и критични за мисията внедрявания. Този канал е достъпен само за клиенти и доставчици на пакета Nextcloud Enterprise.",
    "Stable" : "Стабилна",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Последната стабилна версия. Подходяща е за ежедневно ползване и се актуализации до последната главна версия.",
    "Beta" : "Бета",
    "A pre-release version only for testing new features, not for production environments." : "Версия само за тестване на нови функционалности, която не е подходяща за ползване в производствена среда.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> приложения нямат налична съвместима версия за тази версия на Nextcloud.","<strong>%n</strong> от приложенията нямат налична съвместима версия за тази версия на Nextcloud."],
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Моля, имайте предвид, че уеб актуализатора не се препоръчва за използване от повече от 100 потребители! Моля, вместо това използвайте програмата за актуализиране на командния ред!",
    "Please use the command line updater to update." : "Моля, използвайте програмата за актуализиране на командния ред, за да актуализирате.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Можете да промените канала за актуализиране по-долу, който също засяга страницата за управление на приложения. Например, след като преминете към бета канала, актуализациите на бета приложенията ще ви бъдат предложени в страницата за управление на приложенията.",
    "Update channel:" : "Канал за актуализиране:",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Забележете, че след нова версия, актуализацията се показва само след първата второстепенна версия или по-късно. Ние въвеждаме нови версии, разпределени във времето за нашите потребители и понякога пропускаме версия, когато бъдат открити проблеми. Научете повече за актуализациите и каналите за пускане на адрес {link}",
    "Checked on {lastCheckedDate}" : "Проверено на {lastCheckedDate}"
},
"nplurals=2; plural=(n != 1);");
